<?php
// +----------------------------------------------------------------------
// | likeadmin快速开发前后端分离管理后台（PHP版）
// +----------------------------------------------------------------------
// | 欢迎阅读学习系统程序代码，建议反馈是我们前进的动力
// | 开源版本可自由商用，可去除界面版权logo
// | gitee下载：https://gitee.com/likeshop_gitee/likeadmin
// | github下载：https://github.com/likeshop-github/likeadmin
// | 访问官网：https://www.likeadmin.cn
// | likeadmin团队 版权所有 拥有最终解释权
// +----------------------------------------------------------------------
// | author: likeadminTeam
// +----------------------------------------------------------------------

namespace app\adminapi\lists\device;


use app\adminapi\lists\BaseAdminDataLists;
use app\common\model\device\Device;
use app\common\model\land\LandDevice;
use app\common\model\land\Land;
use app\common\lists\ListsSearchInterface;
use think\facade\Db;


/**
 * Device列表
 * Class DeviceLists
 * @package app\adminapi\listsdevice
 */
class DeviceLists extends BaseAdminDataLists implements ListsSearchInterface
{


    /**
     * @notes 设置搜索条件
     * @return \string[][]
     * @author likeadmin
     * @date 2023/11/24 15:30
     */
    public function setSearch(): array
    {
        return [
            '%like%' => ['d.name'],
            '=' => ['d.user_id', 'd.code', 'd.type', 'd.status', 'd.is_online', 'd.is_bind'],
        ];
    }

    public function querySearch(): array
    {
        $queryWhere = [];
        if (!empty($this->params['land_id'])) {
            $queryWhere['lp.land_id'] = $this->params['land_id'];
        }
        if (!empty($this->params['product_id'])) {
            $queryWhere['pd.product_id'] = $this->params['product_id'];
        }
        return $queryWhere;
    }

    public function userSearch(): array
    {
        $userWhere['d.user_id'] = -1;
        // 超级管理员数据
        if ($this->adminInfo['root'] && !$this->adminInfo['user_id']) {
            unset($userWhere['d.user_id']);
        }
        // 普通用户数据
        if (!$this->adminInfo['root'] && $this->adminInfo['user_id']) {
            $userWhere['d.user_id'] = $this->adminInfo['user_id'];
        }
        return $userWhere;
    }

    /**
     * @notes 获取列表
     * @return array
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     * @author likeadmin
     * @date 2023/11/24 15:30
     */
    public function lists(): array
    {
        return Db::name('device')->alias('d')
            ->where($this->searchWhere)->where($this->userSearch())->where($this->querySearch())
            ->leftJoin('user u','u.id = d.user_id')
            ->leftJoin('farm f','f.user_id = u.id')
            ->leftJoin('product_device pd','pd.device_id = d.id')
            ->leftJoin('product p','p.id = pd.product_id')
            ->field('d.*, u.account, pd.product_id, p.name as product_name, f.id as farm_id, f.farm_name')
            ->limit($this->limitOffset, $this->limitLength)
            ->order(['d.id' => 'desc'])
            ->select()->each(function($item, $key){
                $monitorItemArray = [];
                if (!empty($item['monitor_item'])) {
                    $monitorItemArray = explode(',', $item['monitor_item']);
                }
                $item['monitor_item'] = $monitorItemArray;
                return $item;
            })
            ->toArray();
    }


    /**
     * @notes 获取数量
     * @return int
     * @author likeadmin
     * @date 2023/11/24 15:30
     */
    public function count(): int
    {
        return Db::name('device')->alias('d')->where($this->searchWhere)->where($this->userSearch())->where($this->querySearch())
            ->leftJoin('user u','u.id = d.user_id')
            ->leftJoin('product_device pd','pd.device_id = d.id')
            ->leftJoin('product p','p.id = pd.product_id')
            ->leftJoin('land_product lp','lp.product_id = pd.product_id')
            ->leftJoin('land l','l.id = lp.land_id')
            ->count();
    }

}