<?php
// +----------------------------------------------------------------------
// | likeadmin快速开发前后端分离管理后台（PHP版）
// +----------------------------------------------------------------------
// | 欢迎阅读学习系统程序代码，建议反馈是我们前进的动力
// | 开源版本可自由商用，可去除界面版权logo
// | gitee下载：https://gitee.com/likeshop_gitee/likeadmin
// | github下载：https://github.com/likeshop-github/likeadmin
// | 访问官网：https://www.likeadmin.cn
// | likeadmin团队 版权所有 拥有最终解释权
// +----------------------------------------------------------------------
// | author: likeadminTeam
// +----------------------------------------------------------------------

namespace app\adminapi\logic\farm;


use app\common\model\farm\Farm;
use app\common\logic\BaseLogic;
use think\facade\Db;


/**
 * Farm逻辑
 * Class FarmLogic
 * @package app\adminapi\logic\farm
 */
class FarmLogic extends BaseLogic
{


    /**
     * @notes 添加
     * @param array $params
     * @return bool
     * @author likeadmin
     * @date 2024/01/09 18:22
     */
    public static function add(array $params): bool
    {
        Db::startTrans();
        try {
            Farm::create([
                'user_id' => $params['user_id'],
                'farm_name' => $params['farm_name'],
                'farm_type' => $params['farm_type'],
                'breed_type' => $params['breed_type'],
                'form_scale' => $params['form_scale'],
                'master' => $params['master'],
                'master_contact' => $params['master_contact'],
                'province' => $params['province'],
                'city' => $params['city'],
                'area' => $params['area'],
                'street' => $params['street'],
                'village' => $params['village'],
                'bridge' => $params['bridge'],
                'address' => $params['address'],
                'image' => $params['image'],
            ]);

            Db::commit();
            return true;
        } catch (\Exception $e) {
            Db::rollback();
            self::setError($e->getMessage());
            return false;
        }
    }


    /**
     * @notes 编辑
     * @param array $params
     * @return bool
     * @author likeadmin
     * @date 2024/01/09 18:22
     */
    public static function edit(array $params): bool
    {
        Db::startTrans();
        try {
            Farm::where('id', $params['id'])->update([
                'farm_name' => $params['farm_name'],
                'farm_type' => $params['farm_type'],
                'breed_type' => $params['breed_type'],
                'form_scale' => $params['form_scale'],
                'master' => $params['master'],
                'master_contact' => $params['master_contact'],
                'province' => $params['province'],
                'city' => $params['city'],
                'area' => $params['area'],
                'street' => $params['street'],
                'village' => $params['village'],
                'bridge' => $params['bridge'],
                'address' => $params['address'],
                'image' => $params['image'],
            ]);

            Db::commit();
            return true;
        } catch (\Exception $e) {
            Db::rollback();
            self::setError($e->getMessage());
            return false;
        }
    }


    /**
     * @notes 删除
     * @param array $params
     * @return bool
     * @author likeadmin
     * @date 2024/01/09 18:22
     */
    public static function delete(array $params): bool
    {
        return Farm::destroy($params['id']);
    }


    /**
     * @notes 获取详情
     * @param $params
     * @return array
     * @author likeadmin
     * @date 2024/01/09 18:22
     */
    public static function detail($params): array
    {
        return Farm::findOrEmpty($params['id'])->toArray();
    }

    public static function datas($params)
    {
        $queryWhere = [];
        if (!empty($params['farm_name'])) {
            $queryWhere[] = ['farm_name', 'like', '%' . $params['farm_name'] . '%'];
        }
        $lists = Db::name('farm')->where($queryWhere)->order(['id' => 'desc'])->select()->toArray();
        foreach ($lists as &$item) {
            $item['farminfo'] = 'ID：' . $item['id'] . ' / 名称：' . $item['farm_name'];
        }
        return $lists;
    }
}